@@ -210,6 +210,7 @@ uniBlocks = {
     (0x10D00, 0x10D3F): "Hanifi Rohingya",
     (0x10E60, 0x10E7F): "Rumi Numeral Symbols",
     (0x10E80, 0x10EBF): "Yezidi",
+    (0x10EC0, 0x10EFF): "Arabic Extended-C",
     (0x10F00, 0x10F2F): "Old Sogdian",
     (0x10F30, 0x10F6F): "Sogdian",
     (0x10F70, 0x10FAF): "Old Uyghur",
@@ -241,11 +242,13 @@ uniBlocks = {
     (0x11A50, 0x11AAF): "Soyombo",
     (0x11AB0, 0x11ABF): "Unified Canadian Aboriginal Syllabics Extended-A",
     (0x11AC0, 0x11AFF): "Pau Cin Hau",
+    (0x11B00, 0x11B5F): "Devanagari Extended-A",
     (0x11C00, 0x11C6F): "Bhaiksuki",
     (0x11C70, 0x11CBF): "Marchen",
     (0x11D00, 0x11D5F): "Masaram Gondi",
     (0x11D60, 0x11DAF): "Gunjala Gondi",
     (0x11EE0, 0x11EFF): "Makasar",
+    (0x11F00, 0x11F5F): "Kawi",
     (0x11FB0, 0x11FBF): "Lisu Supplement",
     (0x11FC0, 0x11FFF): "Tamil Supplement",
     (0x12000, 0x123FF): "Cuneiform",
@@ -253,7 +256,7 @@ uniBlocks = {
     (0x12480, 0x1254F): "Early Dynastic Cuneiform",
     (0x12F90, 0x12FFF): "Cypro-Minoan",
     (0x13000, 0x1342F): "Egyptian Hieroglyphs",
-    (0x13430, 0x1343F): "Egyptian Hieroglyph Format Controls",
+    (0x13430, 0x1345F): "Egyptian Hieroglyph Format Controls",
     (0x14400, 0x1467F): "Anatolian Hieroglyphs",
     (0x16800, 0x16A3F): "Bamum Supplement",
     (0x16A40, 0x16A6F): "Mro",
@@ -278,6 +281,7 @@ uniBlocks = {
     (0x1D000, 0x1D0FF): "Byzantine Musical Symbols",
     (0x1D100, 0x1D1FF): "Musical Symbols",
     (0x1D200, 0x1D24F): "Ancient Greek Musical Notation",
+    (0x1D2C0, 0x1D2DF): "Kaktovik Numerals",
     (0x1D2E0, 0x1D2FF): "Mayan Numerals",
     (0x1D300, 0x1D35F): "Tai Xuan Jing Symbols",
     (0x1D360, 0x1D37F): "Counting Rod Numerals",
@@ -285,9 +289,11 @@ uniBlocks = {
     (0x1D800, 0x1DAAF): "Sutton SignWriting",
     (0x1DF00, 0x1DFFF): "Latin Extended-G",
     (0x1E000, 0x1E02F): "Glagolitic Supplement",
+    (0x1E030, 0x1E08F): "Cyrillic Extended-D",
     (0x1E100, 0x1E14F): "Nyiakeng Puachue Hmong",
     (0x1E290, 0x1E2BF): "Toto",
     (0x1E2C0, 0x1E2FF): "Wancho",
+    (0x1E4D0, 0x1E4FF): "Nag Mundari",
     (0x1E7E0, 0x1E7FF): "Ethiopic Extended-B",
     (0x1E800, 0x1E8DF): "Mende Kikakui",
     (0x1E900, 0x1E95F): "Adlam",
@@ -317,6 +323,7 @@ uniBlocks = {
     (0x2CEB0, 0x2EBEF): "CJK Unified Ideographs Extension F",
     (0x2F800, 0x2FA1F): "CJK Compatibility Ideographs Supplement",
     (0x30000, 0x3134F): "CJK Unified Ideographs Extension G",
+    (0x31350, 0x323AF): "CJK Unified Ideographs Extension H",
     (0xE0000, 0xE007F): "Tags",
     (0xE0100, 0xE01EF): "Variation Selectors Supplement",
     (0xF0000, 0xFFFFF): "Supplementary Private Use Area-A",
